@@ -764,7 +764,7 @@ void DynamicAABBTreeCollisionManager_Array::update(const std::vector<CollisionOb
 void DynamicAABBTreeCollisionManager_Array::collide(CollisionObject* obj, void* cdata, CollisionCallBack callback) const
 {
   if(size() == 0) return;
-  switch(obj->getCollisionGeometry()->getNodeType())
+  switch(obj->collisionGeometry()->getNodeType())
   {
 #if FCL_HAVE_OCTOMAP
   case GEOM_OCTREE:
@@ -788,7 +788,7 @@ void DynamicAABBTreeCollisionManager_Array::distance(CollisionObject* obj, void*
 {
   if(size() == 0) return;
   FCL_REAL min_dist = std::numeric_limits<FCL_REAL>::max();
-  switch(obj->getCollisionGeometry()->getNodeType())
+  switch(obj->collisionGeometry()->getNodeType())
   {
 #if FCL_HAVE_OCTOMAP
   case GEOM_OCTREE:
